@@ -23,9 +23,9 @@ our @EXPORT_OK = qw(
                );
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-24'; # DATE
+our $DATE = '2023-02-21'; # DATE
 our $DIST = 'Getopt-Long-Complete'; # DIST
-our $VERSION = '0.316'; # VERSION
+our $VERSION = '0.317'; # VERSION
 
 # we don't want to always load Getopt::Long to avoid startup overhead.
 our ($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER) = (0..2); # copied from Getopt::Long
@@ -149,7 +149,7 @@ Getopt::Long::Complete - A drop-in replacement for Getopt::Long, with shell tab
 
 =head1 VERSION
 
-This document describes version 0.316 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2021-08-24.
+This document describes version 0.317 of Getopt::Long::Complete (from Perl distribution Getopt-Long-Complete), released on 2023-02-21.
 
 =head1 SYNOPSIS
 
@@ -191,7 +191,7 @@ Example:
  my %opts;
  GetOptionsWithCompletion(
      sub {
-         my %args  = @_;
+         my %args  = @_; # see Complete::Getopt::Long for details on what arguments are provided
          my $word  = $args{word}; # the word to be completed
          my $type  = $args{type}; # 'optname', 'optval', or 'arg'
          my $opt   = $args{opt}; # can be an array of options if ambiguous, e.g. ['--on-fail', '--on-full']
@@ -383,9 +383,9 @@ perlancar <perlancar@cpan.org>
 
 =head1 CONTRIBUTOR
 
-=for stopwords Steven Haryanto (on Asus Zenbook)
+=for stopwords Steven Haryanto
 
-Steven Haryanto (on Asus Zenbook) <stevenharyanto@gmail.com>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 CONTRIBUTING
 
@@ -400,13 +400,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2020, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
